@@ -659,7 +659,10 @@ class ListValidator(BaseValidator):
                     value = None
                 result.append(value)
             except ValidationError, e:
-                errors.extend((ix, msg) for fieldname, msg in e.errors)
+                if len(e.errors) == 1 and e.errors[0][0] is None:
+                    errors.append((ix, e.errors[0][1]))
+                else:
+                    errors.append((ix, e.errors))
         if errors:
             raise ValidationError(errors)
         return result
